tlslite.errors.TLSValidationError

Package tlslite :: Module errors :: Class TLSValidationError |
[show private | hide private]
[frames | no frames]

## Class TLSValidationError

         Exception --+
                     |
              TLSError --+
                         |
    TLSAuthenticationError --+
                             |
                            TLSValidationError

The Checker has determined that the other party's certificate chain is invalid.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net